CHANGELOG
=========

1.0.2(2017-04-29)
-----------------

- Updating .gitignore to ignore sphinx builds
- Updating docs

1.0.1(2017-04-29)
-----------------

- Added docs
- Readme enhanced
- BUGFIX: Added a correction to the validators evaluation with the AND connector
- Added flake8 to CI
- Added tox

1.0.0 (2017-04-09)
------------------

- Initial release